# $Id: Car.pl,v 1.1 1996/07/26 05:15:28 pedja Exp $
# Car.pl: converted from the original Car.wos
# The original file contains the following notice:
#
# You may freely copy, distribute, and reuse the code in this example.
# NeXT disclaims any warranty of any kind, expressed or  implied, as to its
# fitness for any particular use.
#
# This is the script file for the third page.  It displays a selected car. 

package WO::DodgeLite::Car;
use WOPerl;

@IVARS=qw(customerChoice package option);
%FLAGS=(
  'rawSet' => 1,
#  'traceSet' => 1,
#  'traceGet' => 1,
#  'traceInvoke' => 1,
);

sub awake
{ 
  my $self=shift;
  #print "Car awake\n";
  # Create a dictionary to hold the customer's choices
  my $cc=$WOApp->customerChoice;
  #print "Customer choice: ",$cc->DESCR,"\n";
  $self->{'customerChoice'}=$cc;
  if (nil($self->{'customerChoice'})) {
    #Another way to set things:
    obj($self)->setCustomerChoice({});
  }
    
  # The customerChoice is a session variable of the application
  # In other word, each session (customer) will have its own customerChoice
  # variable.  This is important since multiple custmers will interact
  # with the app at the same time.
#  $WOApp->setCustomerChoice($self->{'customerChoice'});
  return;
}

sub setSelectedCar
{
  my($self,$aCar)=@_;
  # The whole page is parameterized by aCar.
  # This method initializes the customerChoice dictionary with aCar,
  # sets a default color (white), and selects no options.
  my $cc=$self->{'customerChoice'};
  $cc->removeAllObjects;
  $cc->setObjectForKey($aCar,"car");
  $cc->setObjectForKey("white","color");
  $cc->setObjectForKey(NSMutableArray->array,"selectedPackages");
  # Note: if pl data types are used, the following line is really neccessary!!
  $WOApp->setCustomerChoice($cc);
  return;
}

sub selectedCar
{
  my $self=shift;
  return $self->{'customerChoice'}->objectForKey("car");
}

sub selectedColor {
  my $self=shift;
  return $self->{'customerChoice'}->objectForKey("color");
}

sub selectedPackages {
  my $self=shift;
  return $self->{'customerChoice'}->objectForKey("selectedPackages");
}

sub availablePackages
{
  my $self=shift;
  # This method returns all the available packages for the selected car
  my $packageNames = $self->selectedCar->objectForKey("packages");
  my $packagesEnumerator = $packageNames->objectEnumerator;
  my $availablePackages = NSMutableArray->array;
  my $packagesDict = $WOApp->packagesDict;
  my $aPackage;
    
  while (!nil($aPackage = $packagesEnumerator->nextObject)) {
    $availablePackages->addObject($packagesDict->objectForKey($aPackage));
  }
  return $availablePackages;
}

# The packageClick method is the action that is invoked when a user selects
# an option.
sub packageClick
{
  my $self=shift;
  my $selectedPackages = $self->selectedPackages;
    
  # The package is not selectable, ignore the click.
  if (!$self->isEnabled($self->{'package'})) { return $self; }

  #print "Selected packages: ",$selectedPackages->DESCR,"\n";
  #print "Package: ",$self->{'package'}->DESCR,"\n";
  if ($selectedPackages->containsObject($self->{'package'})) {
    # The package is already selected, so unselect it.
    $selectedPackages->removeObject($self->{'package'});
  } else {
    # Add the newly selected package to the selection
    $selectedPackages->addObject($self->{'package'});
  }
  $WOApp->setCustomerChoice($self->{'customerChoice'});
  return $self;
}

sub isEnabled
{
  my($self,$aPackage)=@_;
  my $selectedPackages = $self->selectedPackages;
  my($optionList, $pack, $packagesEnumerator);
  
  if (!$selectedPackages->containsObject($aPackage)) {
    $optionList=$aPackage->objectForKey("options");
    $packagesEnumerator = $selectedPackages->objectEnumerator;
    while (!nil($pack = $packagesEnumerator->nextObject)) {
      if(!nil($optionList->firstObjectCommonWithArray(
		$pack->objectForKey("options")))) {
	return 0;
      }
    }
  }
  return 1;
}

sub packagePicture {
  my $self=shift;
  my $selectedPackages = $self->selectedPackages;
    
  if (!$self->isEnabled($self->{'package'})) {
    return "../Images/Buttons/Disabled.gif";
  }
  if ($selectedPackages->containsObject($self->{'package'})) {
    return "../Images/Buttons/Selected.gif";
  } else {
    return "../Images/Buttons/Available.gif";
  }
}


sub carModelPicture
{
  my $self=shift;
  return $WOApp->modelsDict
    ->objectForKey($self->selectedCar->objectForKey("model"))
    ->objectForKey("picture");
}

sub colorPicture
{
  my $self=shift;
  return $WOApp->colorsDict
    ->objectForKey($self->selectedColor)
    ->objectForKey("picture");
}

# Save the selected car color when the image map is clicked.
sub setColor
{
  my($self,$colorName)=@_;
  $self->{'customerChoice'}->setObjectForKey($colorName,"color");
  return $self;
}

#  These actions are triggered by clicking on a color band
#  in the active image showing the colors offered for the selected car.
sub selectColorBlack { $_[0]->setColor("black"); }
sub selectColorWhite { $_[0]->setColor("white"); }
sub selectColorAqua { $_[0]->setColor("aqua"); }
sub selectColorBlue { $_[0]->setColor("blue"); }
sub selectColorGrey { $_[0]->setColor("grey"); }
sub selectColorNitro { $_[0]->setColor("nitro"); }
sub selectColorRed { $_[0]->setColor("red"); }

# Compute the price of all the selected options.
sub optionsPrice
{
  my $self=shift;
  my $packagesEnumerator = $self->selectedPackages->objectEnumerator;
  my $aPackage;
  my $total = 0;
    
  while (!nil($aPackage = $packagesEnumerator->nextObject)) {
    $total = $total + $aPackage->objectForKey("price");
  }
  return $total;
}

# Compute the price of the car including the selected options.
sub totalPrice
{
  my $self=shift;
  return $self->selectedCar->objectForKey("basePrice")
         + $self->optionsPrice();
}

# Go to the Dealers page.
sub dealersPage { return $WOApp->pageWithName("Dealers"); }

# Go to the Leasing page.
sub leasingPage { return $WOApp->pageWithName("Leasing"); }

# Go to the Car page.
sub carPage { return $WOApp->pageWithName("Car"); }


'WO::DodgeLite::Car';
# EOF
